from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_comments', '0003_add_submit_date_index'),
    ]

    operations = [
        migrations.AlterField(
            model_name='comment',
            name='is_removed',
            field=models.BooleanField(
                db_index=True, default=False,
                help_text='Check this box if the comment is inappropriate. '
                          'A "This comment has been removed" message will be displayed instead.',
                verbose_name='is removed'),
        ),
        migrations.AlterField(
            model_name='comment',
            name='object_pk',
            field=models.CharField(max_length=64, db_index=True, verbose_name='object ID'),
        ),
    ]



from django.contrib.contenttypes.views import shortcut
from django.urls import path, re_path

from django_comments.feeds import LatestCommentFeed

from custom_comments import views


feeds = {
    'comments': LatestCommentFeed,
}

urlpatterns = [
    path('post/', views.custom_submit_comment),
    path('flag/<int:comment_id>/', views.custom_flag_comment),
    path('delete/<int:comment_id>/', views.custom_delete_comment),
    path('approve/<int:comment_id>/', views.custom_approve_comment),

    re_path(r'^cr/(\d+)/(.+)/$', shortcut, name='comments-url-redirect'),

    path('rss/comments/', LatestCommentFeed()),
]



"""
Module to store compatiblity imports to prevent Django deprecation warnings.
"""
try:
    # Introduced in Django 3.0.
    from django.utils.http import url_has_allowed_host_and_scheme
except ImportError:
    from django.utils.http import is_safe_url as url_has_allowed_host_and_scheme



from django.core.management import call_command

from django_comments.models import Comment

from . import CommentTestCase
from testapp.models import Article


class CommentManagerTests(CommentTestCase):

    def testDoesNotRemoveWhenNoStaleComments(self):
        self.createSomeComments()
        initial_count = Comment.objects.count()

        call_command("delete_stale_comments", "--yes", verbosity=0)

        self.assertEqual(initial_count, Comment.objects.count())

    def testRemovesWhenParentObjectsAreMissing(self):
        self.createSomeComments()
        initial_count = Comment.objects.count()
        article_comments_count = Comment.objects.for_model(Article).count()
        self.assertGreater(article_comments_count, 0)

        # removing articles will not remove associated comments
        Article.objects.all().delete()
        self.assertEqual(initial_count, Comment.objects.count())

        call_command("delete_stale_comments", "--yes", verbosity=0)

        self.assertEqual(0, Comment.objects.for_model(Article).count())
        self.assertEqual(initial_count - article_comments_count, Comment.objects.count())



from django.contrib.contenttypes.views import shortcut
from django.urls import path, re_path

from .views.comments import post_comment, comment_done
from .views.moderation import (
    flag, flag_done, delete, delete_done, approve, approve_done,
)


urlpatterns = [
    path('post/', post_comment, name='comments-post-comment'),
    path('posted/', comment_done, name='comments-comment-done'),
    path('flag/<int:comment_id>/', flag, name='comments-flag'),
    path('flagged/', flag_done, name='comments-flag-done'),
    path('delete/<int:comment_id>/', delete, name='comments-delete'),
    path('deleted/', delete_done, name='comments-delete-done'),
    path('approve/<int:comment_id>/', approve, name='comments-approve'),
    path('approved/', approve_done, name='comments-approve-done'),

    re_path(r'^cr/(\d+)/(.+)/$', shortcut, name='comments-url-redirect'),
]



from django.urls import include, path
from django.contrib.auth.views import LoginView, LogoutView


urlpatterns = [
    path('', include('django_comments.urls')),

    # Provide the auth system login and logout views
    path('accounts/login/', LoginView.as_view(template_name='login.html')),
    path('accounts/logout/', LogoutView.as_view()),
]



from django.core.management.base import BaseCommand

from django_comments.models import Comment


class Command(BaseCommand):
    help = ("Remove comments for which the related objects "
            "don't exist anymore!")

    def add_arguments(self, parser):
        parser.add_argument(
            '-y', '--yes', default='x', action='store_const', const='y',
            dest='answer', help='Automatically confirm deletion',
        )

    def handle(self, *args, **kwargs):
        verbose = kwargs['verbosity'] >= 1
        answer = kwargs['answer']

        # -v0 sets --yes
        if not verbose:
            answer = 'y'

        for comment in Comment.objects.all():
            if comment.content_object is None:
                if verbose:
                    self.stdout.write(
                        "Comment `%s' to non-existing `%s' with PK `%s'" %
                        (comment, comment.content_type.model, comment.object_pk))

                while answer not in 'yn':
                    answer = input("Do you wish to delete? [yN] ")
                    if not answer:
                        answer = 'x'
                        continue
                    answer = answer[0].lower()

                if answer == 'y' :
                    comment.delete()

                    if verbose:
                        self.stdout.write("Deleted comment `%s'" % comment)
